==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/InsertBlock/ts/InsertBlock_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>InsertBlock</name>
    <message>
        <location filename="../InsertBlock.js" line="+108"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../InsertBlockInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;I ブロック挿入</translation>
    </message>
    <message>
        <location filename="../InsertBlock.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>回転:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation>ブロック回転&lt;br&gt;この角度で</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale X:</source>
        <translation>スケールX:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation>X軸ブロック拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation>Y軸ブロック拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Keep Proportions</source>
        <translation>比率保持</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation>ブロック反転&lt;br&gt;水平</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation>ブロック反転&lt;br&gt;垂直</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Single Block</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <location filename="../InsertBlockDialog.ui" line="+14"/>
        <source>Array of Blocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InsertBlockDialog.ui" line="+12"/>
        <source>Columns:</source>
        <translation>列:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Rows:</source>
        <translation>行:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Column Spacing:</source>
        <translation>列間隔:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Row Spacing:</source>
        <translation>行間:</translation>
    </message>
</context>
<context>
    <name>Paste</name>
    <message>
        <source>Rotation:</source>
        <translation type="obsolete">回転:</translation>
    </message>
    <message>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation type="obsolete">ブロック回転&lt;br&gt;この角度で</translation>
    </message>
    <message>
        <source>Scale X:</source>
        <translation type="obsolete">スケールX:</translation>
    </message>
    <message>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation type="obsolete">X軸ブロック拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <source>Keep Proportions</source>
        <translation type="obsolete">比率保持</translation>
    </message>
    <message>
        <source>Scale Y:</source>
        <translation type="obsolete">スケールY:</translation>
    </message>
    <message>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation type="obsolete">Y軸ブロック拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation type="obsolete">ブロック反転&lt;br&gt;水平</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation type="obsolete">ブロック反転&lt;br&gt;垂直</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/InsertBlock/ts/InsertBlock_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>InsertBlock</name>
    <message>
        <location filename="../InsertBlock.js" line="+108"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../InsertBlockInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;I ブロック挿入</translation>
    </message>
    <message>
        <location filename="../InsertBlock.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>回転:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation>ブロック回転&lt;br&gt;この角度で</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scale X:</source>
        <translation>スケールX:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation>X軸ブロック拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation>Y軸ブロック拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Keep Proportions</source>
        <translation>比率保持</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation>ブロック反転&lt;br&gt;水平</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation>ブロック反転&lt;br&gt;垂直</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Single Block</source>
        <translation>１つのブロック</translation>
    </message>
    <message>
        <location line="+17"/>
        <location filename="../InsertBlockDialog.ui" line="+14"/>
        <source>Array of Blocks</source>
        <translation>ブロックの配列</translation>
    </message>
    <message>
        <location filename="../InsertBlockDialog.ui" line="+12"/>
        <source>Columns:</source>
        <translation>列:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Rows:</source>
        <translation>行:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Column Spacing:</source>
        <translation>列間隔:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Row Spacing:</source>
        <translation>行間:</translation>
    </message>
</context>
<context>
    <name>Paste</name>
    <message>
        <source>Rotation:</source>
        <translation type="obsolete">回転:</translation>
    </message>
    <message>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation type="obsolete">ブロック回転&lt;br&gt;この角度で</translation>
    </message>
    <message>
        <source>Scale X:</source>
        <translation type="obsolete">スケールX:</translation>
    </message>
    <message>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation type="obsolete">X軸ブロック拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <source>Keep Proportions</source>
        <translation type="obsolete">比率保持</translation>
    </message>
    <message>
        <source>Scale Y:</source>
        <translation type="obsolete">スケールY:</translation>
    </message>
    <message>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation type="obsolete">Y軸ブロック拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation type="obsolete">ブロック反転&lt;br&gt;水平</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation type="obsolete">ブロック反転&lt;br&gt;垂直</translation>
    </message>
</context>
</TS>
